{% extends "epic/base_layout.html" %}
{% load crispy_forms_tags %}
{% load static %}

{% block extrahead %}
{{ block.super }}
{% endblock extrahead %}

{% block content %}
{{ block.super }}
{{ datasheet_form.media }}
{{ part_formset.media }}

<form method="POST" enctype="multipart/form-data">
<div class="form-horizontal">
{% crispy datasheet_form %}
</div>
{% crispy part_formset %}

<div class="form-actions">
  <input type="submit" name="save" value="Save" class="btn btn-primary">
  <a href="{{ cancel_url  }}" name="cancel" class="btn btn-default">Cancel</a>
</div>
</form>

<br>

{% endblock content %}
